==> tinxy-0.2.5.tar.gz: tinxy-0.2.5/setup.py <==
import setuptools

with open('README.md', 'r', encoding='utf-8') as fh:
    long_description = fh.read()

setuptools.setup(
    name='tinxy',
    author='Siddhu',
    author_email='me@siddhu.dev',
    description='Tinxy Package',
    keywords='Tinxy, tinxy.in',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/arevindh/tinxy',
    project_urls={
        'Documentation': 'https://github.com/arevindh/tinxy',
        'Bug Reports': 'https://github.com/arevindh/tinxy/issues',
        'Source Code': 'https://github.com/arevindh/tinxy',
        # 'Funding': '',
        # 'Say Thanks!': '',
    },
    package_dir={'': 'src'},
    packages=setuptools.find_packages(where='src'),
    classifiers=[
        # see https://pypi.org/classifiers/
        'Development Status :: 5 - Production/Stable',

        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',

        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3 :: Only',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
    install_requires=['js2py','asyncio','requests','simplejson','tinxy'],
    extras_require={
        'dev': ['check-manifest'],
        # 'test': ['coverage'],
    },
    # entry_points={
    #     'console_scripts': [  # This can provide executable scripts
    #         'run=examplepy:main',
    # You can execute `run` in bash to run `main()` in src/examplepy/__init__.py
    #     ],
    # },
)

==> tinxy-0.2.6.tar.gz: tinxy-0.2.6/setup.py <==
import setuptools

with open('README.md', 'r', encoding='utf-8') as fh:
    long_description = fh.read()

setuptools.setup(
    name='tinxy',
    author='Siddhu',
    author_email='me@siddhu.dev',
    description='Tinxy Package',
    keywords='Tinxy, tinxy.in',
    version='0.2.6',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/arevindh/tinxy',
    project_urls={
        'Documentation': 'https://github.com/arevindh/tinxy',
        'Bug Reports': 'https://github.com/arevindh/tinxy/issues',
        'Source Code': 'https://github.com/arevindh/tinxy',
        # 'Funding': '',
        # 'Say Thanks!': '',
    },
    package_dir={'': 'src'},
    packages=setuptools.find_packages(where='src'),
    classifiers=[
        # see https://pypi.org/classifiers/
        'Development Status :: 5 - Production/Stable',

        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',

        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3 :: Only',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
    install_requires=['js2py','asyncio','requests','simplejson'],
    extras_require={
        'dev': ['check-manifest'],
        # 'test': ['coverage'],
    },
    # entry_points={
    #     'console_scripts': [  # This can provide executable scripts
    #         'run=examplepy:main',
    # You can execute `run` in bash to run `main()` in src/examplepy/__init__.py
    #     ],
    # },
)
